"""
Tests for solicitor.py
"""
from ingest_envoy.solicitor import Solicitor

solicitor = Solicitor("test/input_files/test-metadata.json")
expected_metadata = {
    "fileSetIds": "16B-069_sb32814386_1_001.57685.66193635417",
    "workflowName": "std_calibration",
    "systemId": "2",
    "creationTime": "2021-07-06T21:50:48",
    "productLocator": "uid://evla/execblock/48ba4c9d-d7c7-4a8f-9803-1115cd52459b",
    "projectMetadata": {
        "projectCode": "16B-069",
        "title": "JVLA monitoring of an in-progress extreme scattering event",
        "telescope": "EVLA",
        "startTime": "57685.661952546296",
        "observer": "Keith Bannister",
    },
    "destinationDirectory": "/lustre/aoc/cluster/pipeline/docker/workspaces/spool/tmp576dknjp",
}


class TestSolicitor:
    def test_solicit_contents(self):
        metadata = solicitor.solicit_contents()
        assert metadata == expected_metadata

    def test_solicit_workflow_directory_name(self):
        expected_workflow_dir_name = "tmp576dknjp"

        name = solicitor.solicit_workflow_directory_name()
        assert name == expected_workflow_dir_name

    def test_solicit_processing_creation_time(self):
        expected_corrected_time = "2021_07_06T21_50_48"

        time_string = solicitor.solicit_processing_creation_time()
        assert time_string == expected_corrected_time

    def test_solicit_parameters(self):
        expected_parameters = {
            "sdmId": "16B-069_sb32814386_1_001.57685.66193635417",
            "telescope": "EVLA",
            "workflowName": "std_calibration",
            "workflowRequestId": "2",
            "spl": "uid://evla/execblock/48ba4c9d-d7c7-4a8f-9803-1115cd52459b",
            "processingStart": "2021_07_06T21_50_48",
            "destinationDir": "/lustre/aoc/cluster/pipeline/docker/workspaces/spool/tmp576dknjp",
            "workflowDir": "tmp576dknjp",
        }

        parameters = solicitor.solicit_parameters()
        assert parameters == expected_parameters
