from pathlib import Path

from tqdm import tqdm

from .interfaces import FetchProgressReporter


class ProgressNonReporter(FetchProgressReporter):
    """
    Reports no progress as files complete. Useful as a default and for testing.
    """

    def complete(self, path: Path):
        """Does nothing with the fact that some files are complete."""


class ProgressBarReporter(FetchProgressReporter):
    """
    Display progress bar as the files are fetched.
    """

    def __init__(self, total):
        self.progress = tqdm(total=total, unit="byte", unit_scale=True, unit_divisor=1024)

    def complete(self, path: Path):
        self.progress.update(path.stat().st_size)
